This function displays a brief report about the results of running the Inspector algorithm on a list of GWAS result files. The full report including plots, cleaned files and summary statistics are generated and saved in the output folder during the algorithm run.
result.inspector(inspector)An instance of '>Inspector class. Check setup.inspector for more details.
A data.table containing a brief report about the results.